# SpectroMiner
Spectrominer is a software that allows you to apply corrections to mass spectrometry data.
More precisely, it uses control measures in order to subtract the natural presence of isotopes.

Project Status: in development

## Installation
### Windows
see the [releases](https://github.com/ulaval-rs/spectrominer/releases)

To run spectrominer, run the .exe.

### Macos
#### From the release
see the [releases](https://github.com/ulaval-rs/spectrominer/releases)

#### From PyPi
Installation through PyPi is also possible.
Be sure [brew](https://brew.sh/) is installed,
and from the terminal:
```bash
$ brew install python3
$ brew install python-tk
```
And then:
```bash
$ pip install spectrominer
```

### PyPi
To install:
```bash
$ pip install spectrominer
```
To run spectrominer:
```bash
$ spectrominer
```
or
```bash
$ /path/to/python/bin/spectrominer
```
